@@ -6,7 +6,7 @@
 # @File    : __init__.py.py
 # @Software: PyCharm
 from nonebot import on_command
-from nonebot.adapters.cqhttp import Bot, Event, Message
+from nonebot.adapters.onebot.v11 import Bot, MessageEvent, Message
 
 from .run import run
 
@@ -14,11 +14,12 @@ runcode = on_command('code', priority=5)
 
 
 @runcode.handle()
-async def _(bot: Bot, event: Event):
+async def _(bot: Bot, event: MessageEvent):
     code = str(event.get_message()).strip()
     res = await run(code)
     await runcode.send(message=Message(res), at_sender=True)
 
+
 __usage__ = """
 发送
 code [语言] [-i] [inputText]
@@ -32,7 +33,7 @@ code [语言] [-i] [inputText]
 运行代码示例(python)(有输入)：
     code py -i 你好
         print(input())
-        
+
 目前仅支持c/cpp/c#/py/php/go/java/js
 运行于：https://glot.io/
 """
@@ -40,4 +41,4 @@ code [语言] [-i] [inputText]
 __help_plugin_name__ = "在线运行代码"
 
 __permission__ = 2
-__help__vesion__ = '0.1'
\ No newline at end of file
+__help__vesion__ = '0.1'
